Learn R Programming

mycolorsTB (version 0.1.1)

view_palette: Display a color palette

Description

Generates a ggplot visualization of a specified package palette.

Usage

view_palette(palette_name = "mycolors")

Value

A ggplot object showing the colors of the chosen palette.

Arguments

palette_name

The name of the palette to display ("mycolors", "classicTB", or "pathogenomics").

Examples

Run this code
view_palette("mycolors")
view_palette("classicTB")

Run the code above in your browser using DataLab