powered by
Generates a ggplot visualization of a specified package palette.
view_palette(palette_name = "mycolors")
A ggplot object showing the colors of the chosen palette.
The name of the palette to display ("mycolors", "classicTB", or "pathogenomics").
view_palette("mycolors") view_palette("classicTB")
Run the code above in your browser using DataLab